goscripts

package
v0.0.0-...-4778944 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 7, 2026 License: MIT Imports: 14 Imported by: 0

Documentation

Overview

Package goscripts provides entry points for project-local build scripts.

The functions in this package are designed to be called from .goscript files in your project's bin/.goscripts/ directory. This allows project-specific customization while using the lix framework version from your go.mod.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Build

func Build(args []string) error

Build handles all build commands.

Subcommands:

  • (none): Full build (routes, templ, tailwind, go build)
  • routes: Generate routes/urls/urls.go only
  • assets: Build routes + templ + tailwind (no go build)

Flags:

  • --watch: Enable watch mode for templ and tailwind
  • --devserver: Enable Go watcher and run the app (requires --watch)
  • -p, --port: Port for the dev server

Types

This section is empty.

Jump to